@@ -8,6 +8,7 @@ Date : 08-Jun-2020
 from functools import wraps
 import re
 from copy import deepcopy
+from types import MethodType, FunctionType
 
 from .exceptions import FieldError, MissingFieldError, FieldTypeError, FieldValueError
 from .customtypearg import BaseArg
@@ -43,6 +44,7 @@ class FunctionArgPreProcessor:
             data_type = type_definition.pop('data_type', None)
             validator = type_definition.pop('validator', None)
             nested = type_definition.pop('nested', None)
+            default_value = type_definition.pop('default', None)
             type_definition.pop('description', None)
             print_key = f"{parent}.{key}" if parent else key
             if self.is_non_empty_value(value):
@@ -50,6 +52,8 @@ class FunctionArgPreProcessor:
                     parsed_args[alias_key] = validator(print_key, value)
                 else:
                     parsed_args[alias_key] = self.parse_value(print_key, value, data_type, nested, **type_definition)
+            elif default_value is not None:
+                parsed_args[alias_key] = self.get_value(default_value)
             elif required:
                 raise MissingFieldError(print_key)
         if self.is_strict and self.is_non_empty_value(params):
@@ -86,8 +90,8 @@ class FunctionArgPreProcessor:
             self.check_constraint(value, key, **value_constraints)
         return value
 
-    @staticmethod
-    def check_constraint(value, key, min_val=None, max_val=None, value_list=None, regex=None,
+    @classmethod
+    def check_constraint(cls, value, key, min_val=None, max_val=None, value_list=None, regex=None,
                          regex_error_message=None, min_len=None, max_len=None):
         """
         To check the value for constraints. The caller of this function provides only the value and key as positional
@@ -104,30 +108,32 @@ class FunctionArgPreProcessor:
         :param max_len: Maximum length of the field
         :return:
         """
-        if min_val and value < min_val:
+        min_val = cls.get_value(min_val)
+        max_val = cls.get_value(max_val)
+        if min_val is not None and value < min_val:
             raise FieldValueError(ErrorCode.FIELD_MIN_RANGE_VIOLATED, key,
                                   f"{key} should be greater than or equal to {min_val}",
                                   {"minValue": min_val})
-        if max_val and value > max_val:
+        if max_val is not None and value > max_val:
             raise FieldValueError(ErrorCode.FIELD_MAX_RANGE_VIOLATED, key,
                                   f"{key} should be lesser than or equal to {max_val}",
                                   {"maxValue": max_val})
-        if value_list and value not in value_list:
+        if value_list is not None and value not in value_list:
             raise FieldValueError(ErrorCode.FIELD_VALUE_NOT_IN_ALLOWED_LIST, key,
                                   f"{key} should be one of these - {value_list}", {"allowedValue": value_list})
         if hasattr(value, '__len__'):
             try:
                 length = len(value)
-                if min_len and length < min_len:
+                if min_len is not None and length < min_len:
                     raise FieldValueError(ErrorCode.FIELD_MIN_LENGTH_VIOLATED, key,
                                           f"{key} has a minimum length of {min_len}", {"minLength": min_len})
-                if max_len and length > max_len:
+                if max_len is not None and length > max_len:
                     raise FieldValueError(ErrorCode.FIELD_MAX_LENGTH_VIOLATED, key,
                                           f"{key} has a maximum length of {max_len}", {"maxLength": max_len})
             except TypeError:
                 pass
 
-        if regex and re.search(regex, value) is None:
+        if regex is not None and re.search(regex, value) is None:
             message = regex_error_message if regex_error_message else f"{key} should be of format - {regex}"
             raise FieldValueError(ErrorCode.FIELD_REGEX_VALIDATION_FAILED, key, message, {"regex": regex})
 
@@ -172,3 +178,9 @@ class FunctionArgPreProcessor:
         if (isinstance(value, list) or isinstance(value, dict)) and not value:
             return False
         return True
+
+    @staticmethod
+    def get_value(value):
+        if isinstance(value, FunctionType) or isinstance(value, MethodType):
+            return value()
+        return value
